var APIBase = require("../../api.base");
var system = require("../../../system");
var settings = require("../../../../config/settings");
class ActionAPI extends APIBase {
    constructor() {
        super();
        this.originSve = system.getObject("service.channel.originSve");
        this.channelSve = system.getObject("service.channel.channelSve");
        this.channelmerchantSve = system.getObject("service.channel.channelmerchantSve");
        this.platformchannelService = system.getObject("service.channel.platformchannelSve" );
    }
    /**
     * 接口跳转
     * action_process  执行的流程
     * action_type     执行的类型
     * action_body     执行的参数
     */
    async springboard(pobj, qobj, req) {
        var result;
        if (!pobj.action_process) {
            return system.getResult(null, "action_process参数不能为空");
        }
        if (!pobj.action_type) {
            return system.getResult(null, "action_type参数不能为空");
        }
        try {
            result = await this.handleRequest(pobj.action_process, pobj.action_type, pobj.action_body);
        } catch (error) {
            console.log(error);
        }

        return result;
    }

    async handleRequest(action_process, action_type, action_body) {
        var opResult = null;
        switch (action_type) {

            // 来源api
            case "originDics":
                opResult = await this.originSve.dics(action_body);
                break;
            case "originInfo":
                opResult = await this.originSve.info(action_body);
                break;
            case "originMerchants":
                opResult = await this.originSve.merchants(action_body);
                break;

            // 渠道api
            case "channelSuggest":
                opResult = await this.channelSve.suggest(action_body);
                break;
            case "channelDicts":
                opResult = await this.channelSve.dics(action_body);
                break;
            case "channelInfo":
                opResult = await this.channelSve.info(action_body);
                break;
            case "channelSave":
                opResult = await this.channelSve.save(action_body);
                break;
            case "channelPage":
                opResult = await this.channelSve.page(action_body);
                break;

            // 商户api
            case "merchantInfo":
                opResult = await this.channelmerchantSve.info(action_body);
                break;
            case "merchantSave":
                opResult = await this.channelmerchantSve.save(action_body);
                break;
            case "merchantPage":
                opResult = await this.channelmerchantSve.page(action_body);
                break;
            case "getPushMerchantIds" :
                opResult = await  this.channelmerchantSve.getPushMerchantIds(action_body);
                break;
    
            //渠道绑定
            case  "bindPlatform":
                opResult = await  this.platformchannelService.bindPlatform(action_body);
                break;
            //绑定渠道推送
            case "pushbindingchannel" :
                opResult = await  this.platformchannelService.pushbindingchannel(action_body);
                break;

            default:
                opResult = system.getResult(null, "action_type参数错误");
                break;
        }
        return opResult;
    }
    exam() {
        return `<pre><pre/>`;
    }
    classDesc() {
        return {
            groupName: "op",
            groupDesc: "元数据服务包",
            name: "ActionAPI",
            desc: "此类是对外提供接口服务",
            exam: "",
        };
    }
    methodDescs() {
        return [
            {
                methodDesc: `<pre><pre/>`,
                methodName: "springboard",
                paramdescs: [
                    {
                        paramDesc: "请求的行为，传递如：sjb",
                        paramName: "action_process",
                        paramType: "string",
                        defaultValue: null,
                    },
                    {
                        paramDesc: "业务操作类型，详情见方法中的描述",
                        paramName: "action_type",
                        paramType: "string",
                        defaultValue: null,
                    },
                    {
                        paramDesc: "业务操作类型的参数，action_body必须传递的参数有，times_tamp（时间戳，类型int）、sign(签名,类型string)，其余的为业务需要的参数",
                        paramName: "action_body",
                        paramType: "json",
                        defaultValue: null,
                    }
                ],
                rtnTypeDesc: `<pre><pre/>`,
                rtnType: `<pre><pre/>`
            }
        ];
    }
}
module.exports = ActionAPI;
